#
# spec file for package stress-ng
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           stress-ng
Version:        0.06.12
Release:        1.1
Summary:        Tool to load and stress a computer
License:        GPL-2.0
Group:          System/Benchmark
Url:            http://kernel.ubuntu.com/~cking/stress-ng/
Source:         http://kernel.ubuntu.com/~cking/tarballs/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  keyutils-devel
BuildRequires:  libaio-devel
BuildRequires:  libattr-devel
BuildRequires:  libbsd-devel
BuildRequires:  libcap-devel
BuildRequires:  libseccomp-devel
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
stress-ng can stress various subsystems of a computer. It can stress load CPU,
cache, disk, memory, socket and pipe I/O, scheduling and much more. stress-ng
is a re-write of the original stress tool by Amos Waterland but has many
additional features such as specifying the number of bogo operations to run,
execution metrics, a stress verification on memory and compute operations and
considerably more stress mechanisms.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
make %{?_smp_mflags}

%install
install -D -p -m 0755 stress-ng   %{buildroot}%{_bindir}/stress-ng
install -D -p -m 0644 stress-ng.1 %{buildroot}%{_mandir}/man1/stress-ng.1

%files
%defattr(-,root,root)
%doc COPYING README
%{_bindir}/stress-ng
%{_mandir}/man1/stress-ng.1%{ext_man}

%changelog
* Sat Jul 16 2016 mpluskal@suse.com
- Update to version 0.06.12:
  * Makefile: bump version once more
  * Update manual page date since we've touched the manual
  * stress-seal: don't abort fatally if memfd_create is not
    available.
  * fast-test-all: cater for non-fatal test exit status
  * Add oom-pipe to fast-test-all exclusion list
  * Manual: clarify that return code 3 could refer to missing
    system call
  * stress-fcntl: handle EAGAIN lock requests more robustly
  * stress-fcntl: don't check initial GETLK status
  * stress-icache: don't fail if advice fails on EINVAL
- Changes for version 0.06.11
  * Makefile; bump version
  * fast-test-all: don't run seccomp, it may not pass on some
    kernels
  * stress-fault: handle segfaults that occur on some BSD kernels
  * stress-icache: only madvice if MADV_NOHUGEPAGE is defined
  * stress-icache: don't assume that read/write/exec protection is
    allowed
  * Update cache-mfence helper. It supports ARM now.	Zhiyi Sun
- Changes for version 0.06.10:
  * Makefile: bump version again
  * stress-atomic + build: the autodetect smarts did not work, fix
    them
- Changes for 0.06.09:
  * Makefile: bump version
  * stress-atomic: don't make tmp volatile, fixes clang warnings
  * Add smarts to Makefile to detect if atomic GCC functions are
    supported
- Changes for 0.06.08:
  * Makefile: bump version
  * Manual: update date
  * stress-ptrace: EINTR is not a failure on waitpid
  * stress-tlb-shootdown: remove case where < 2 CPUs abort the test
  * Add GCC atomic ops stressor
  * stress-copy-file-range: handle ENOSPC as non-fatal
  * stress-icache: call __clear_cache() between code modifications.
  * Enable icache stressor for arm
  * Add renameat2 to syscalls
  * Add preadv2/prwritev2 to syscalls
  * stress-lockbus: se GCC builtin __atomic_add_fetch to test lock
    bus for ARMv6-v8.
  * stress-epoll: void return on timer_settime
  * Manual: update contributors, add Zhiyi Sun
* Tue Jul 12 2016 mpluskal@suse.com
- Use correct rpm group
* Tue Jul  5 2016 mpluskal@suse.com
- Update to version 0.06.07:
  * Makefile: bump version
  * stress-msg: add in IPC_INFO, MSG_INFO, MSG_STAT msgctl calls
  * stress-vecmath: add more ops to make vecmath more demanding
  * stress-sync-file: sync on mode rather than on the sync_modes index
  * stress-opcode: use __builtin___clear_cache to avoid clang warning
  * stress-get: fix typo on syscall name
  * replace mfence with __sync_synchronize builtin
  * stress-bigheap: remove redundant call to stress_get_pagesize
- Changes for version 0.06.07:
  * Makefile: bump version
  * stress-shm-sysv: don't msync on GNU HURD, it is not implemented
  * stress-shm: don't msync on GNU HURD, it is not implemented
  * stress-ng: build in OPT_MEMFD_BYTES case if STRESS_MEMFD defined
  * manual: fcntl: add in missing locking commands
  * stress-socket: add --sock-type socket type option
  * Add Linux open file description locks stressor
  * Add POSIX advisory locking stressor
  * stress-fcntl: add more locking fcntl commands
  * man page: add --taskset example
  * stress-memfd: add better termination exit points, don't fail on EXNIO
  * stress-memfd: add a --memfd-bytes size specifier option
  * perf + Makefile: Add some smarts to detect available perf enums
  * stress-shm: msync the shm region
  * stress-shm-sysv: msync the shm region
  * stress-memfd: add hole punching to memory
  * stress-mremap: add MAP_FIXED remappings
  * stress-memfd: add random madvise to add some more page stress
  * stress-memfd: add seeks to memfd stressor
  * stress-xattr: rename name to attrname to stop shadowing on name
  * Update README stress test count
  * Add in missing seccomp from the --help info
  * Add a fcntl SEAL command stressor
  * README: update number of tests
  * time_now: return -1.0 for failed time fetch
  * stress-get: add getcpu system call
  * stress-dup: only close fd's that are open
- Changes for version 0.06.05:
  * Makefile: bump version
  * stress-mmap: ensure we don't leak fd, cleanup on exit
  * fast-test-all: don't run exec test
  * stress-mremap: catch SEGV and OOM restarts
  * stress-mmap: catch SEGV and OOM restarts
  * fast-test-all: exclude pty
  * Revert "stress-mremap: add random MAP_FIXED option to mremap"
  * stress-zero: #if def around ptr declarion for non-Linux systems
  * stress-zero: only perform /dev/zero mmapping on Linux
  * stress-cacheflush: remove sys_cacheflush for non linux systems
  * stress-shm-sysv: SHM_INFO and IPC_INFO are linux only
  * stress-cache: only call cacheflush on Linux systems
  * stress-filename: filename option should be from the .opt field
  * stress-rtc: fix some overly pedantic warnings from cppcheck
  * stress-shm: sync, expand and shrink shm region, extra stress
  * stress-open: use different forms of open flag combinations
  * stress-zero: mmap /dev/zero and check if the contents is zero
  * stress-pipe: sanity check pipe size setting
  * stress-dup: add dup2 on same fd exerciser
  * stress-fcntl: add some more fcntl commands
  * stress-seek: add SEEK_CUR, SEEK_END seek options
  * stress-utime: exercise UTIME_NOW and UTIME_OMIT settings
  * stress-userfaultfd: add poll to add some more kernel coverage
  * Add stress_set_nonblock to set fd to non-blocking I/O
  * stress-userfaultfd: add in zeropage handling
  * stress-mremap: add random MAP_FIXED option to mremap
  * stress-readahead: remove redundant if defined() checks on fadvise
  * Add SIGHUP trapping and send SIGALRM to all processes on death
  * stress-personality: only print number of personalities in instance 0
  * syscalls: update pause information
  * stress-cache: use cacheflush() on systems that provide this syscall
  * syscalls: update ioctl entry
  * perf: add "per" / marking for per second
  * Add pty stressor
  * Add semtimedop to syscalls, it is present in stress-sem-sysv.c
  * stress-cap: add capset call for current stressor process
  * stress-shm-sysv: add some additional exercising of shmctl commands
  * stress-sem-sysv: exercise more of the semctl commands
  * Add trivial chown stressor
  * stress-dup: use dup3() on linux if it is available
  * Makefile: vecmath: make the file touch silent
  * stress-key: add request_key system call
  * syscalls: update pipe2 entry, this is now being exercised by
  * stress-pipe
  * stress-mq: memset sigev to zero
  * stress-madvise: only build in if STRESS_MADVISE defined
  * Add madvise stressor
  * syscalls: add mq_timedsend to mq
  * stress-mq: use timed and non-timed versions of send/receive
  * stress-mq: add mq_notify calls every 1024 iterations
  * stress-link: lstat the link
  * Widen metrics dump stressor name field to 13 chars
- Changes for version 0.06.04:
  * Makefile: bump version
  * Makefile: remove gcc coverage build flags
  - these were accidentally added in the previous release and not
    removed
- Changes for version 0.06.03:
  * Makefile: bump version
  * stress-cap: cap data needs _LINUX_CAPABILITY_U32S_3 elements in size
  * stress-nice: add some randomness to the delay to unsync nicenesses
  * stress-opcode: remove white spaces
* Wed May 18 2016 liedke@rz.uni-mannheim.de
- stress-ng (0.06.02-1) unstable; urgency=medium
  * Makefile: bump version
  * Makefile + stress-vecmath: add more smarts to detect gcc build failures
  * stress-af-alg: don't fatally fail on bind on AF_ALG
  * stress-af-alg: fix up error messages
  * Add stackmmap stressor
  * stress-stack: ensure signal handling stack is aligned
  * stress-context: ensure stack is aligned to 64 byte boundaries
  * stress-opcode: disable signal count tracking
  * stress-opcode: clean up code a little
  * Add opcode stressor
  * update syscalls.txt
  * stress-ioprio: perform some io writes to exercise i/o priorities
  * Add ioprio stressor
- stress-ng (0.06.01-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-af-alg: avoid any unterminated strings (unlikely)
  * debian/control: add libcap-dev to Build-Depends
  * stress-hdd: should use SIZEOF_ARRAY instead of sizeof
  * stress-full: don't close fd before trying a read
  * stress-af-alg: ensure the rng read size is correct
  * stress-af-alg: fix more -ve fd closes
  * stress-af-alg: don't close fd that is -ve
  * stress-tlb-shootdown: fix incorrect comparison on ENOMEM
  * stress-af-alg: check for errors on setsockopt
  * stress-full: try read test rather than skip if write fails
  * stress-full: clear buffer before we write
- stress-ng (0.06.00-1) unstable; urgency=medium
  * Makefile: new major version and codename
  * stress-msync: cast off_t to intmax_t to print with %%jd format specifier
  * debian/control: update Standards Version to 3.9.8
  * manual: update date
  * stress-msync: add in conditional STRESS_MSYNC build check
  * stress-af-alg: add simple rng to the mix
  * stress-af-alg: remove redundant type field info
  * manual: rephrase the --seq description
  * manual: clean up the SEE ALSO section
  * Add TLB shootdown stressor
  * stress-af-alg: remove (void)name
  * Add /dev/full stressor
  * stress-urandom: where possible also read data from /dev/random
  * Manual: update af-alg skciper section.
  * stress-hdd: work through all the --hdd-opts if --maximize is enabled
  * stress-xattr: fix error messages, they were reporting wrong syscall
  * stress-af-alg: use array size so we don't need NULL sentinels
  * stress-af-alg: Add skcipher stessing
  * stress-procfs: add /proc/tty, /proc/self, /proc/thread_self
  * stress-key: Add some more keyctl calls
  * Rename stressor names to match their command line name
  * Add msync stressor
  * Fix non-Linux build for set_cpu_affinity
  * stress-rtc: also read /proc/driver/rtc
  * Add RTC stressor
  * stress-get: use prlimit only with glibc >= 2.13.0
  * stress-procfs: add more /proc directory traversal
  * stress-inotify: add ioctl FIONREAD to peek at available data on fd
  * Add the CPU affinity option '--taskset'
  * stress-cache: make pinned a linux only variable
  * stress-cache: fix pinned message, swap cpu and instance around
  * stress-cache: fix failure to build on GNU/HURD
  * Update contributions authors in manual
  * Ensure processes are kept to the CPU affinity set
  * taskset -c 4-7 stress-ng --cache 4 --stream 4 --yield 4
  * Update README with other OS build notes
  * stress-spawn: make this a Linux only test
  * Disable MLOCKED sections for now on SunOS, we get linker issues
  * stress-ng: correct casts of void *
  * stress-ng: include alloca.h for SunOS
  * stress-ng: cater for systems that don't support RLIMIT_NPROC
  * mincore: cater for SunOS mincore API difference
  * stress-yield: correct casts of void *
  * stress-yield: include alloca.h for SunOS
  * stress-vm: correct casts of void *
  * stress-stream: correct casts of void *
  * stress-str: include strings.h for SunOS builds for index() prototype
  * stress-stack: include alloca.h for SunOS
  * stress-sigsuspend: correct casts of void * and uint64_t *
  * stress-mmapmany: correct casts of void * and uint8_t *
  * stress-mmap: correct casts of void * and uint8_t *
  * Fix alignment mask to ensure stacks are 16 byte aligned (LP: #1573117)
  * stress-mlock: correct casts of void * and uint8_t *
  * stress-icache: cast addr to (void *) in mprotect calls
  * mounts: SunOS requires *BSD style build arrangements
  * stress-hdd: cast data to (void *) to silence warning
  * stress-hdd: don't use futimes for Solaris UNIX
  * Add logging to syslog of free memory info post-OOM
  * Add system and memory syslog logging
  * stress-brk: catch EAGAIN errors on sbrk/brk
  * Remove debug log test message
  * stress-socket-fd: only build stressor if STRESS_SOCK_FD defined
  * Add logging of who and how stress-ng was invoked to syslog
- stress-ng (0.05.25-1) unstable; urgency=medium
  * Makefile: bump version
  * debian/control: update standards version to 3.9.7
  * Ensure all clone() calls are 16 byte aligned for aarch64 (LP: #1573117)
- stress-ng (0.05.24-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-mmap: handle SIGBUS signals (LP: #1569468)
  * stress-mmapmany: sanity check sysconf return
  * stress-mmapmany: detect SEGV deaths
  * stress-mlock: detect SEGV deaths
  * stress-brk: detect SEGV deaths
  * stress-bigheap: detect SEGV deaths
  * stress-memfd: detect SEGV deaths
  * stress-mmapmany: allocate mappings on heap rather than stack
  * stress-mlock: allocate mappings on heap rather than stack
  * stress-cpu: move sieve buffer to static to reduce stack size
  * stress-sem*: differentiate between which semaphore init that failed
  * stress-remap-file-pages: abort if remap fails
  * stress-fiemap: remove \n from pr_fail_err messages
* Tue Apr 12 2016 liedke@rz.uni-mannheim.de
- stress-ng (0.05.23-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-aio: fix segfault on --maximumize option (LP: #1568335)
  * stress-chmod: just instance 0 should create the file (LP: #1568333)
- stress-ng (0.05.22-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-af-alg: retry open if we get EAFNOSUPPORT (LP: #1564786)
- stress-ng (0.05.21-1) unstable; urgency=medium
  * Makefile: bump version
  * Add test-cap.c to Makefile dist rule
  * debian: tests: don't run remap stressor
  * stress-ng: add klog (syslog) stressor
  * syscalls: add remap_file_pages
  * Add page remapping stressor
  * stress-pthread: Add get_robust_list call
  * stress-sysinfo: exercise fstatfs()
  * Move wcs options to correct postion in manual
  * Add the sync-file stressor
  * Add fp-error stressor
  * syscalls.txt: update some missing syscalls and some re-ordering
  * Add sys/capability.h and capget build time checks
  * stress-get: add prlimit
  * Update syscalls.txt with capget stressor
  * Add capabilities stressor
- stress-ng (0.05.20-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-getdent: fix build warnings on systems with no getdents syscalls
  * Manual: update date
  * Debian/changelog: fix spelling mistake
  * stress-udp: fix two warnings on uninitialised addr
  * stress-socket-fd: fix two scan-build warnings
  * stress-getdent: init ret to -ENOSYS, fix scan-build warning
  * Use the generic signal handler helpers
  * helper: add generic signal handling/restoring helper functions
  * stress-oom-pipe: use stress_get_file_limit
  * stress-open: use stress_get_file_limit
  * stress-dup: use stress_get_file_limit
  * stress-socket-fd: use stress_get_file_limit
  * helper: add stress_get_file_limit to get max open files allowed
  * Add sockfd stressor
  * Add getdent stressor
  * stress-filename: use strncpy rather than strcpy
  * stress-qsort: use calloc
  * stress-cpu: zeta method should be counting in integers
  * stress-mergesort: use calloc
  * stress-heapsort: use calloc
  * stress-bsearch: use calloc
- stress-ng (0.05.19-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-switch: don't initialize buf_size twice
  * stress-ng: don't stress-sleep options unless STRESS_SLEEP defined
  * stress-shm-sysv: comparing j < i - 1 is incorrect when i = 0
  * stress-shm-sysv: parent should close read end of pipe
  * stress-context: make stacks larger, avoid segfault on kFreeBSD
  * stress-oom-pipe: handle condition where pipe size can't be set
  * stress-pipe: use O_DIRECT when possible
  * stress-switch: use O_DIRECT with 1 byte buffer is possible
  * stress-oom-pipe: ensure sz is set before we check it against prev_sz
  * Add stress-oom-pipe pipe buffer stressor
  * helper: fix comment on system_read()
  * stress-fallocate: add in default mode 0
  * stress-iosync: fix build warning when using old glibc:
  * stress-fstat: add blacklist of paths not to open/fstat/close
  * correctly spell stress_adjust_pthread_max
  * stress-str: make some statics into static const
  * stress-socket: make socket_opts static const
  * stress-maxtrix: make some statics static const
  * stress-vm: make some statics static const
  * stress-wcstr: make variables static const
  * stress-get: make priorities static const
  * stress-filename: make filename_opts static const
  * stress-dentry: make dentry_removals static const
  * stress-cpu: make some variables static const
  * stress-clone: make flags and unshare flags static const
  * stress-chmod: make modes static const
  * perf: make perf_tp_info static const
  * cache: make struct generic_map const
  * helper: make stress_temp_path static const
  * stress-udp-flood: make data static const
  * stress-spawn: make exec strings static
  * Only define OPT_PTHREAD* macros if STRESS_PHREAD is defined
  * Minor #define changes, no functional change
  * stress-cpu: remove redundant initialisation of last_e
  * stress-cpu: don't build _Decimal stressors with clang
  * stress-shm-sysv: set entire shm_ids array to -1
  * stress-fork: make child exit immediately and stash pid only in parent
  * stress-xattr: free buffer on error exit path
  * stress-timerfd: fix timer thresholding check
  * Add sleep stressor
  * stress-clock: add some comments and make source 80 column friendly
  * bigheap: reorder some variables on the stack for better packing
  * Add whitespace in return statement
  * thermal-zone: minor clean up
  * net: make loop iterator size_t
  * cache: minor code tweaks, no functional changes
  * cache: rework get_contents error return paths
  * cache: reformat function declarations to match the stress-ng code style
  * clean up and rename macro mk_path to MK_PATH
  * Ensure we do not under run string buffer
  * Add apparmor_parser excutable check
  * time: make source 80 column friendly
  * thermal-zone: make source 80 column friendly
  * sched: make source 80 column friendly
  * perf: make source 80 column friendly
  * mlock: make source 80 column friendly
  * limit.c: remove redundant #includes
  * io-priority: make source 80 column friendly
  * ignite-cpu: make source 80 column friendly
  * Include stress-ng.h first for __kernel_long_t and __kernel_ulong_t
* Sat Feb 20 2016 liedke@rz.uni-mannheim.de
  stress-ng (0.05.18-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-eventfd: fix incorrect return check on eventfd (LP: #1547450)
  * stress-mknod: fix == comparison on errno (LP: #1547446)
  * stress-tee: catch EINTR in splice() calls (LP: #1547434)
  stress-ng (0.05.17-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-aio: don't cancel the signal handler before exiting (LP: #1547108)
  * stress-lockf: don't return failure if we get a timeout (LP: #154107)
  * stress-aio: don't return failure if we get a timeout (LP: #1547090)
  * Check for ENOMEM ENOSPC errors during init (LP: #1547062)
  * make stress_temp_dir_mk and stress_temp_dir_rm return -errno on failure
  * stress-dentry: fix file striding on clean-up (LP: #1547004)
  * Add stress_get_prime64 to stress-ng header
  * Add stress_get_prime64 to find a prime for filename striding
  * typedef possibly missing __kernel_long_t and __kernel_ulong_t
  * Add <linux/posix_types.h> for linux builds
  * stress-aio-linux: fix clang scan-build warning
  * Makefile: only do build time config detection when building target
  stress-ng (0.05.16-1) unstable; urgency=medium
  * Makefile: bump version
  * Makefile: add test-libaio.c to dist rule
  * stress-seccomp: EINTR on waitpid is not a failure, so ignore it
  * stress-numa: aborted test should not be a failure, nothing got tested
  * stress-quota: check for EPERM, abort if we don't have permission
  * stress-kcmp: check for EPERM, abort if we don't have permission
  * debian/control: add libaio-dev dependency
  * stress-aio: use aiolib instead of direct system calls
  * Catch faults in child stressor and flag them as a fatal failure
  * stress-socket: only build in sendmmsg test for glibc 2.14 or higher
  * stress-iosync: build in syncfs call for glibc 2.14 or higher
  * Add detection for <linux/seccomp.h>
  * stress-handle: only build in if we have glibc 2.14 or higher
  * ignite-cpu: don't print failure message as inf, make it dbg
  * stress-malloc: calloc'd size is too big, fix the size (LP: #1544575)
  * mincore: page align address of buffer before passing it to mincore
* Thu Feb 11 2016 liedke@rz.uni-mannheim.de
  stress-ng (0.05.15-1) unstable; urgency=medium
  * Makefile: bump version
  * fast-test-all: add pass/fail summary at end
  * fast-test-all: fix typo, socket-pair should be sockpair
  * stress-handle: specify width of integer in sscanf
  * Manual: expand the error exit code notes
  * stress-qsort: cast data to (uint8_t *) to stop static analysis warnings
  * stress-hdd: close file on a fstat failure
  * stress-futex: add backoff delay if futex is too much in contention
  * stress-sendfile: ignore EINTR on sendfile calls
  * stress-readahead: handle -ENOSPC as a non-failure condition
  * stress-vm-rw: re-organise the code into parent/child helpers
  * stress-userfaultfd: set stack size to be STACK_SIZE
  * stress-hdd: handle -ENOSPC as a non-failure condition
  * adt: remove socket-pair from tests
  * cache helper: output cache allocation size
  * stress-cpu-online: only report root requirement on instance 0
  * stress-cpu-online: Don't report a failure if not run as root
  * Add L before cache level to make the debug less abstract
  * stress-denty: ENOSPC should not be a fatal error that stops the test
  * Fix -x option, compare munged strings to treat '_' like '-'
  * Ensure pathological class is disabled if we don't enable --pathological
  * stress-zlib: fix comparison which should not be an assignment
  * helper: fix double free on error exit
  stress-ng (0.05.14-1) unstable; urgency=medium
  * Makefile: bump version
  * Fix make dist - typo in test-libpthread.c
  * stress-fiemap: initialise counter at start of loop
  * stress-fiemap: ensure counter is being updated
  * adt: exclude bind mount from list of stressors
  * Don't emit warning on --pathological if number of stressors is zero
  * ignite-cpu: add null entry at end of list, don't scan by array size
  * Only include <sys/mount.h> for linux for the bind mount stressor
  * stress-bind-mount: build stressor if STRESS_BIND_MOUNT defined
  * stress-bind-mount: stop cppcheck whining about uninitialised pid
  * stress-numa: don't fatally fail on -EIO with MPOL_MF_STRICT (LP: #1542741)
  * Enabled IGNITE_CPU with the --aggressive option
  * Add bind-mount stressor (LP: #1542010)
  * Add --ignite-cpu option to maximize CPU frequency
  * Make float decimal auto detect set -DHAVE_FLOAT_DECIMAL
  * Minor re-org of Makefile, and add more files to dist rule
  * Update README - increase number of stressors
  * adt tests: remove membarrier, it fails on older kernels in Debian
  * Add some more comments
  * stress-affinity: handle EINVAL when CPU(s) are offline
  * Set number of instances to on-line CPUs if N is -ve (LP: #1513546)
  * Remove opt_long, replace with get_int32 or get_uint64
  * Add libpthread build time checks
  * Add librt build time checks
  * Remove commented out old link line
  * Add libcrypt check
  * Makefile: remove test-libz correctly
  * stress-cpu: make source 80 column friendly
  * Add FORCE_DO_NOTHING macro do force compiler to stop opimizing out loops
  * Add zlib stressor
  * stress-stream: cater for systems without L3 cache
  * stress-stream: only emit cache size info on instance 0
  * Add libbsd-dev to README
  stress-ng (0.05.13-1) unstable; urgency=medium
  * Makefile bump version
  * Makefile: add test-libbsd.c to dist rule
  * adt: Bar a few more tests that can be problematic on different arches
  * stress-fifo: don't return and error status if we have to abort early
  * Exclude tests that may fail because system calls not fully implemented
  * Build stress-mergesort if STRESS_MERGESORT is defined
  * Built stress-heapsort if STRESS_HEAPSORT is defined
  * Make *put globals volatile to force gcc to compute values
  * Add BSD mergesort stressor
  * Add BSD heapsort stressor
  * madvise: add MADV_FREE
  * stress-vm-rw: don't close already closed pipe ends
  * stress-vm: just one top level iteration in rowhammer method
  * Use MAP_SHARED where appropriate
  * stress-qsort: fix typo in comment SIGARLM -> SIGALRM
  * Makefile: call make using $(MAKE)
  * stress-apparmor: reduce scope of ret
  * stress-shm: reduce the scope of variable n
  * stress-shm-sysc: reduce scope of variable n
  stress-ng (0.05.12-1) unstable; urgency=medium
  * Makefile: bump version
  * cache: memset globbuf, work around clang warnings
  * stress-cpu-online: free cpu_online on error return
  * fast-test-all: use the -v verbose flag
  * fast-test-all: Don't yet test copy-file
  * stress-copy-file: only build if syscall is supported
  * Change type of error messages in cache helper
  * cache: use %%zd format specifier for size_t
  * cache: make source 80 column friendly
  * fast-test-all: return with error exit status
  * Tweak man page exit status table
  * Exit with status 2 if a stressor failured
  * Change mini help text to make it consistent
  * Add cpu-online to mini help
  * stress-cache: cater for non-powers of 2 cache size
  * Remove hard #undef __linux__ used during debugging
  * Re-work shared cache buffer allocation
  * stress-memcpy: fix segfault due to changes in allocation of cache buffer
  * Add kcmp to exclude list on adt test
  * Add cpu-online to exclude list on adt test
  * Make some helpers return int32_t rather than long
  * Add WARN_UNUSED macro and use it against functions that need return checks
  * Add CPU online stressor
  * Fix indentation issue after --hdd
  stress-ng (0.05.11-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-stream: make L3 a uint64_t
  * stress-clock: fix build warning on non-Linux systems
  * stress-stream: fix FTBFS on non-Linux systems
  stress-ng (0.05.10-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-stream: use new cache probing api
  * Add James Hunt to contributors in man page
  * cache: constify a few args and (void) fclose returns
  * Makefile: re-order cache.c in source list
  * stress-cache: make source 80 col friendly, use name instead of __func__
  * Removed bogus check.
  * Reduce cache level to maximum available if specified too high.
  * New function to check max cache level. Also, reduced variable scope.
  * Merge branch 'master' into cache-handling
  * Rather than failing, display a message and fall back to defaults.
  * Reduce variable scope and remove redundant assignment.
  * stress-copy-file: off_t should be loff_t
  * Remove debug forced enabled of stress-file-copy
  * Merge branch 'master' into cache-handling
  * Add --cache-level=, --cache-ways=, and --cache-no-affinity to man page.
  * Add linux guard for cpu cache function prototypes.
  * Handle systems not providing cache details via sysfs
  * Dispense with cache.h.
  * get_contents(): Fixed resource leak.
  * Add --copy-file copy_file_range() stress test
  * Fix spelling mistake of "bandwidth"
  * Fix spelling mistake of "weird" in comment
  * man page: Fix formatting on vm stressor method table
  * Fixes for building on non-Linux platforms.
  * Add Linux support to specify cache type and size.
  * Fix column width of vm-method options
  * Fix column width of stream option description
  stress-ng (0.05.09-1) unstable; urgency=medium
  * Makefile: bump version
  * Fix incorrect position of \ in man page
  * stress-udp: fix UDP-Lite enable options
  * stress-af-alg: don't build for non-Linux systems
  * stress-udp: add error checking to setsockopt calls
  * Add auto detection of xattr.h to avoid build failures
  * Add auto detection of keyutils.h to avoid build failures
  * stress-numa: prefix abort message with stressor name
  * stress-udp: in UDP-Lite mode, limit checksum to 8 byte UDP header
  * Fix formatting of --hdd-opts in man page
  * Add --seek-punch option to punch holes in seek file
  * Add UDP-Lite option --udp-lite
  * Align bitfields in flags
  * stress-socketpair: handle ENFILE errors more gracefully
  * stress-filename: only emit filename information on instance 0
  * Add fiemap stressor
  * stress-stream: kludge around a false positive from static analysis
  * Add --stream-l3-size option to specify stream L3 CPU cache size
  * stress-unshare: don't complain on -EINVAL
  * stress-stream: remove extraneous space between cache size and K
  * Use RESTRICT macro as an alias for __restict
  * Add stream memory bandwidth and computation stressor
  * Add 8 more bits to OPT_FLAGS
  * stress-aio: remove unused typedef
  * refactor random string filling using stress_strnrnd()
  * Add AF_ALG socket domain (hash) tester
  * Add more tracing perf events to --perf output
  stress-ng (0.05.08-1) unstable; urgency=medium
  * Makefile: bump version
  * Remove stress-leak.c, it was accidentally added
  * Update man page date
  * Debian control: Use dh_apparmor
  * Fix incorrectly placed #endif around TSEARCH
  * stress-iosync: (void)name if not building for Linux
  * stress-mlock: remove debug message
  * Add in options to *search stressors in mini built-in help
  * Add TSC read stressor
  * Remove some redundant (void)var statements
  * stress-get: rename gettid to sys_gettid to avoid name clash
  * Move uint64_put and double_put from helper.c to stress-ng.h
  * Rename macros STRESS_{MIN|MAX} -> STRESS_{MINIMUM|MAXIMUM}
  * Update debian copyright to 2016
  * Update copyright year to 2016
  * stress-iosync: don't close -ve fd
  stress-ng (0.05.07-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-yield: include signal.h to build on FreeBSD
  * Exclude stressors that cannot be run
  * stress-matrix: add copy and mean methods
  * stress-yield: ensure at least 2 child processes per CPU
  * Update syscalls.txt with syncfs
  * stress-key: remove if def'd debug code
  * stress-iosync: add syncfs() for Linux only
  * Add --sock-nodelay option to disable the Nagle algorithm
  * stress-socket: split out client/server code into separate functions
  * stress-exec: remove (void)name;
  * stress-dentry: add 'random' ordering option
  * stress-affinity: set initial cpu to instance number
  * stress-clock: output name of clock timer id on error
  * Add --temp-path option
  * Debian/control: change priority because of apparmor dependency
  * Add apparmor to excluded adt tests
  * Add sendmsg and sendmmsg to syscalls.txt
  * Add --sock-opts option
  stress-ng (0.05.06-1) unstable; urgency=medium
  * Makefile: bump version
  * Makefile + stress-apparmor: generate binary data using od and sed
  stress-ng (0.05.05-1) unstable; urgency=medium
  * Makefile: bump version
  * Makefile: --no-print-directory is required when make calls itself
  * Add apparmor as a build dependency
  * Makefile: Add test-apparmor.c usr.bin.pulseaudio.eg to make dist dist
  * stress-seccomp: stop build warnings on systems without seccomp
  * Ensure test-appormor build test covers the aa API
  * Remove mwc_seed from mwc.c
  * Add load average stats to --times option
  * inline mwc_seed, faster and shrinks text size a bit
  * stress-apparmor: perform some more devious corruption actions
  * Debian: control: dependency should be libapparmor-dev
  * stress-spawn: move spawn_calls to correct accounting stats
  * Add a posix-spawn stressor
  * Add unshare stressor
  * stress-shm-sysv: ensure all shm_ids are initialised to -1
  * Update Makefile to autogenerate AppArmor binary blob
  * stress-apparmor: add some random bit corruption
  * stress-apparmor: add profile add/replace/remove stressing
  * Debian: control: add libapparmor1 dependency
  * stress-apparmor: #if def global vars
  * README: Add note about requiring GNU make
  * Add initial simple AppArmor test, more features later
  stress-ng (0.05.04-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-userfaultfd: fix 32 bit build warning
  * stress-shm: replace strides of 4096 with page size
  * stress-shm-sysv: replace strides of 4096 with page size
  * stress-mremap: replace strides of 4096 with page size
  * stress-mmap: replace strides of 4096 with page size
  * stress-bigheap: make stride the page size
  * parse-opts: ensure_positive: don't reassign ptr twice
  * stress-daemon: close dup'd fds on exit
  * Add daemon stressor
  * Move set_proc_name into helper, remove proc-name.c
  * helper: make timer slack also depend on __linux__
  * stress_mlock_region: constify args
  * stress_get_stack_direction: constify arg
  * Remove coredump, merge functionality into helper
  * Update README
  * syscalls: add mlock2
  * stress-mlock: add support for mlock2
  * stress-aio: clear io_reqs before use and disable handler later
  * stress-rename: rename between directories
  stress-ng (0.05.03-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-seccomp: avoid build failures on arm64 targets
  stress-ng (0.05.02-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-get: define _DEFAULT_SOURCE to stop gcc 5.2.1 warnings
  * Add new seccomp stressor
  * stress-mmap: fix thinko, init no_mem_retires in correct place
  * stress-shm-sysv: add more allocation smarts
  * stress-shm-sysv: add mmap failure abort and OOM counting
  * stress-shm: add mmap failure abort and OOM counting
  * stress-seek: set a useable upper seek limit for 32 bit arches
  * stress-mmap: add mmap retry mechanism if we can't mmap memory
  * stress-memfd: trap SIGBUS as well as SIGKILL for OOM catching
  * stress-vm: add spacing on OOM restarts message
  * stress-malloc: add spacing on OOM restarts message
  * stress-memfd: add spacing on OOM restarts message
  * stress-vm: add mmap retry mechanism if we can't mmap memory
  * refactor stack direction checking function
  * stress-personality: fix warning on %%lu being used on a size_t
  * stress-ptrace: re-enable this stressor and fix up pr_failed_* macro
  * Enable personality stressor
  stress-ng (0.05.01-1) unstable; urgency=medium
  * Makefile: bump version
  * stress-shm: break out of loops when ok is false
  * stress-fcntl: make F_SETOWN and F_GETOWN linux only for now
  * helper: fix warning on FreeBSD, unused args caused warnings
  * stress-switch: force more context switches
  * stress-pipe: add pipe-data-size and pipe-size options
  * stress-seek: only report error if SEEK_DATA/SEEK_HOLE supported
  * stress-seek: add SEEK_DATA and SEEK_HOLE seeks
  * syscalls.txt: add new userfaultfd syscall
  * Manual: note that userfaultfd is only for Linux
  * Add new userfaultfd stressor
  * stress-membarrier: rename pr_failed_err -> pr_fail_err
  * stress-cpu: force more jmps in cpu-jmp method
  * stress-brk: add occasional brk shrink to add a bit more variety
  * stress-shm-sysv: use some more random shm flags
  * stress-mmap: use some more random mmap flags
  * stress-fallocate: add some more fallocate modes
  * Rename pr_failed_* macros to pr_fail
  * log: rename logging functions
  * log: don't be silent when we have failure messages
  * stress-filename: Add more error handling feedback
  * Update debian/rules: enable debian build flags
  * Fix buffer not null terminated error with strncpy
  * Add filename stressor
  * Add --timer-slack option to adjust timer slackness
  * disable core dump via prctl() to avoid massive core files
  * Signal to child processes if parent has died.
  * log: make variables static
  stress-ng (0.05.00-1) unstable; urgency=medium
  * Makefile: bump version to 0.05.00, update codename
  * man page: fix wrapped line so 'lsearch' is not seen as a macro
  * shm stressors: make final write failures a debug message
  * shm stressors: exit child stressor if pipe write fails
  * Add POSIX shared memory stressor
  * stress-qsort: fix resource leak on error return path
  * man page: make it 80 column tty friendly
  * stress-qsort: bail out when SIGALRM triggers
  * stress-rlimit: disable handlers once we finish to avoid setjmp looping
  * log: remove debug cruft
  * Add --log-file logging option
  * stress-sem*: remove ; after while loop
  * stress-icache: force cache clear using __clear_cache
  * Make source more 80 column friendly
  * manual: clarify number of cpus
  * madvise: fix typo
  * stress-shm-sysv: make shm cleanup robust
  * stress-ng: remove setpgrp() calls
  * stress-sem-sysv: handle signal during setup phase correctly
  * stress-sem: handle signal during setup phase correctly
  * fix -k option: it does not require a parameter
  * stress-procfs: use non-blocking open
* Wed Nov 11 2015 mardnh@gmx.de
- initial package
